@@ -80,7 +80,7 @@ mapaest <- function(y, ppy=NULL, minimumAL=1, maximumAL=ppy, paral=c(0,1,2), dis
       p <- 1
     }
     xreg <- matrix(xreg,ncol=p)
-    # Check that it contains at least n observatoins and trim
+    # Check that it contains at least n observations and trim
     xn <- dim(xreg)[1]
     if (xn < n){
       stop("Number of observations of xreg must be equal of exceed the length of y.")
@@ -301,7 +301,16 @@ mapaest.loop <- function(ALi, y, minimumAL, maximumAL, observations,
       }
       # Turn off warnings for es - this is done when the model reduces pool 
       # due to sample size.
-      fit <- suppressWarnings(es(ats,model=mapa.model,silent="all",xreg=xregA, ...))
+      fittemp <- suppressWarnings(es(ats,model=mapa.model,silent="all",xreg=xregA, ...))
+      # Let's make sure changes in the output of es do not break mapa (again!)
+      acceptres <- c("model","timeElapsed","states","persistence","phi",
+                     "initialType","initial","initialSeason","nParam",
+                     "fitted","forecast","lower","upper","residuals",
+                     "errors","s2","intervals","level","actuals",
+                     "holdout","imodel","cumulative","xreg",
+                     "updateX","initialX","persistenceX","transitionX",
+                     "ICs","cf","cfType","FI","accuracy")
+      fit <- fittemp[unlist(lapply(acceptres,function(x){which(names(fittemp) == x)}))]
             
     }
     
@@ -324,8 +333,8 @@ mapaest.loop <- function(ALi, y, minimumAL, maximumAL, observations,
                   "fitted"=NULL,"forecast"=NULL,"lower"=NULL,
                   "upper"=NULL,"residuals"=NULL,"errors"=NULL,
                   "s2"=NULL,"intervals"=NULL,"level"=NULL,
-                  "actuals"=NULL,"holdout"=NULL,"iprob"=NULL,
-                  "intermittent"=NULL,"xreg"=NULL,"updateX"=NULL,
+                  "actuals"=NULL,"holdout"=NULL,"imodel"=NULL,
+                  "cumulative"=NULL,"xreg"=NULL,"updateX"=NULL,
                   "initialX"=NULL,"persistenceX"=NULL,"transitionX"=NULL,
                   "ICs"=NULL,"cf"=NULL,"cfType"=NULL,"FI"=NULL,
                   "accuracy"=NULL,"use"=FALSE)
@@ -431,6 +440,9 @@ plot.mapa.fit <- function(x,xreg.plot=c(TRUE,FALSE),...){
   maximumAL <- max(ALs)
   ppy <- as.numeric(x[1,idx.ppy])
   
+  # Get permitted seasonal levels
+  perm_seas <- (ppy %% minimumAL:maximumAL) == 0 & (minimumAL:maximumAL < ppy)
+  
   # Plot model selection summary
   ALplot <- 1:(maximumAL-minimumAL+1)
   ALplot <- ALplot[unlist(x[,idx.use])==TRUE]
@@ -521,6 +533,11 @@ plot.mapa.fit <- function(x,xreg.plot=c(TRUE,FALSE),...){
         ylab="Components", xlab="Aggregation Level", main=ttl,breaks=c(-1,0,1,1.5,2,2.5))
   axis(2, at=1:(3+x.add), labels=list("Error","Trend","Season","Xreg")[(3+x.add):1])
   axis(1, at=min(comps[,4+x.add]):max(comps[,4+x.add]))
+  # Grey seasonality
+  k <- 1+x.add 
+  for (AL in which(!perm_seas)){
+    polygon(c((AL-0.5)*c(1,1),(AL+0.5)*c(1,1)),c(.5+k,-.5+k,-.5+k,.5+k),col="gray60",border=NA)
+  }
   box()
   
   for (i in 1:(4+x.add)){
